@@ -50,7 +50,8 @@ function(obj, seg.Z, psi=stop("provide psi"), control = seg.control(), model = T
     interc<-attr(mt,"intercept")
     y <- model.response(mf, "any")
     XREG <- if (!is.empty.model(mt)) model.matrix(mt, mf, contrasts)
-
+    namesXREG0<-colnames(XREG)
+    
     nomeRispo<-strsplit(paste(formula(obj))[2],"/")[[1]]
     if(length(nomeRispo)>=2) mf[nomeRispo[1]]<-weights*y
     
@@ -68,7 +69,8 @@ function(obj, seg.Z, psi=stop("provide psi"), control = seg.control(), model = T
     #XREG<-model.matrix(obj0) non va bene perch non elimina gli eventuali mancanti in seg.Z..
     #Due soluzioni
     #XREG<-XREG[,colnames(model.matrix(obj)),drop=FALSE]
-    XREG<-XREG[,match(c("(Intercept)",all.vars(formula(obj))[-1]),colnames(XREG),nomatch =0),drop=FALSE]
+    #XREG<-XREG[,match(c("(Intercept)",all.vars(formula(obj))[-1]),colnames(XREG),nomatch =0),drop=FALSE]
+    XREG <- XREG[, match(c("(Intercept)", namesXREG0),colnames(XREG), nomatch = 0), drop = FALSE]
     n <- nrow(XREG)
     #Z <- list(); for (i in colnames(XREGseg)) Z[[length(Z) + 1]] <- XREGseg[, i]
     Z<-lapply(apply(XREGseg,2,list),unlist) #prende anche i nomi!
@@ -119,7 +121,9 @@ function(obj, seg.Z, psi=stop("provide psi"), control = seg.control(), model = T
         for(i in 1:ncol(U)) mf[nomiU[i]]<-U[,i]
         Fo <- update.formula(formula(obj), as.formula(paste(".~.+", paste(nomiU, collapse = "+"))))
         #obj <- update(obj, formula = Fo, data = KK)
-        obj <- update(obj, formula = Fo, data = mf)
+        obj <- update(obj, formula = Fo, data = mf, eval=FALSE)
+        if(!is.null(obj[["subset"]])) obj[["subset"]]<-NULL
+        obj<-eval(obj, envir=mf)
         if (model) obj$model <-mf  #obj$model <- data.frame(as.list(KK))
         obj$psi <- psi
         return(obj)
@@ -179,7 +183,9 @@ function(obj, seg.Z, psi=stop("provide psi"), control = seg.control(), model = T
     if(is.matrix(y)&& (fam$family=="binomial" || fam$family=="quasibinomial")){
               mf<-cbind(mf[[1]], mf[,-1])
     }
-    objF <- update(obj0, formula = Fo, data = mf)
+    objF <- update(obj0, formula = Fo, data = mf, evaluate=FALSE)
+    if(!is.null(objF[["subset"]])) objF[["subset"]]<-NULL
+    objF<-eval(objF, envir=mf)
     if(any(is.na(objF$coefficients))){
      stop("some estimate is NA: premature stopping with a large number of breakpoints?",
       call. = FALSE)
